<?PHP // $Id$ 
      // moodle.php - created with Moodle 1.4 development (2004081200)


$string['action'] = '';
$string['active'] = '';
$string['activities'] = '';
$string['activity'] = '';
$string['activityclipboard'] = '  : <b>$a</b<=>';
$string['activityiscurrentlyhidden'] = '    ';
$string['activitymodule'] = ' ';
$string['activityreport'] = ' ';
$string['activityselect'] = '      ';
$string['activitysince'] = '  $a';
$string['add'] = '';
$string['addactivity'] = ' ';
$string['addadmin'] = ' ';
$string['addcreator'] = '   ';
$string['added'] = '  $a';
$string['addedtogroup'] = '    $a';
$string['addedtogroupnot'] = '     $a ';
$string['addedtogroupnotenrolled'] = '     a$      ';
$string['addinganew'] = '   $a ';
$string['addinganewto'] = ' $a->what    $a->to';
$string['addingdatatoexisting'] = '  ';
$string['addnewcategory'] = '  ';
$string['addnewcourse'] = '   ';
$string['addnewuser'] = '  ';
$string['addresource'] = ' ';
$string['address'] = '';
$string['addstudent'] = ' ';
$string['addteacher'] = ' ';
$string['admin'] = ' ';
$string['adminhelpaddnewuser'] = '    ';
$string['adminhelpassignadmins'] = '         ';
$string['adminhelpassigncreators'] = '        ';
$string['adminhelpassignstudents'] = '        ';
$string['adminhelpassignteachers'] = '        ';
$string['adminhelpauthentication'] = '         ';
$string['adminhelpbackup'] = '     ';
$string['adminhelpconfiguration'] = '   ';
$string['adminhelpconfigvariables'] = '       ';
$string['adminhelpcourses'] = '      ';
$string['adminhelpedituser'] = '      ';
$string['adminhelpenrolments'] = '       ';
$string['adminhelpfailurelogs'] = '    ';
$string['adminhelplanguage'] = '    ';
$string['adminhelplogs'] = '    ';
$string['adminhelpmanageblocks'] = '   ';
$string['adminhelpmanagedatabase'] = '(      !)';
$string['adminhelpmanagefilters'] = '     ';
$string['adminhelpmanagemodules'] = '   ';
$string['adminhelpsitefiles'] = '        ';
$string['adminhelpsitesettings'] = '    ';
$string['adminhelpthemes'] = '      ( ....)';
$string['adminhelpuploadusers'] = '      ';
$string['adminhelpusers'] = '     ';
$string['administration'] = ' ';
$string['administrator'] = '';
$string['administrators'] = '';
$string['administratorsall'] = ' ';
$string['administratorsandteachers'] = ' ';
$string['advancedfilter'] = ' ';
$string['again'] = ' ';
$string['all'] = '';
$string['allactivities'] = ' ';
$string['alldays'] = ' ';
$string['allfieldsrequired'] = '  ';
$string['allgroups'] = ' ';
$string['alllogs'] = '  ';
$string['allow'] = '';
$string['allowguests'] = '       ';
$string['allownot'] = ' ';
$string['allparticipants'] = ' ';
$string['alphabet'] = 'áȡʡˡ̡͡ΡϡСѡҡӡԡա֡ء١ڡۡݡޡߡܡ';
$string['alphanumerical'] = '      ';
$string['alreadyconfirmed'] = '   ';
$string['always'] = '';
$string['answer'] = '';
$string['areyousuretorestorethis'] = '   ';
$string['areyousuretorestorethisinfo'] = '                ';
$string['assessment'] = '';
$string['assignadmins'] = ' ';
$string['assigncreators'] = ' ';
$string['assignstudents'] = ' ';
$string['assignstudentsnote'] = ':       ɡ          .';
$string['assignstudentspass'] = '              :\'$a\'';
$string['assignteachers'] = ' ';
$string['authentication'] = '';
$string['autosubscribe'] = '   ';
$string['autosubscribeno'] = ':      ';
$string['autosubscribeyes'] = ':        ';
$string['availability'] = '';
$string['availablecourses'] = '  ';
$string['backup'] = ' ';
$string['backupcoursefileshelp'] = '           ';
$string['backupdate'] = '  ';
$string['backupdetails'] = '   ';
$string['backupfilename'] = '    ';
$string['backupfinished'] = '   ';
$string['backupincludemoduleshelp'] = '              ';
$string['backupkeephelp'] = '          ǿ(   ';
$string['backuplogdetailed'] = '  ';
$string['backuploglaststatus'] = '  ';
$string['backuplogshelp'] = '            .';
$string['backupnameformat'] = '     ';
$string['backuporiginalname'] = '     ';
$string['backupsavetohelp'] = '           <br> (       )';
$string['backupuserfileshelp'] = '       (:   )    ';
$string['backupusershelp'] = '                ';
$string['backupversion'] = '  ';
$string['blockdeleteconfirm'] = '     \'$ a\'  .          .         ';
$string['blockdeletefiles'] = '     \'$a->block\'     .    (     )          $a->directory';
$string['blocks'] = '';
$string['blocksetup'] = '  ';
$string['blocksuccess'] = '$a      ';
$string['bycourseorder'] = '   ';
$string['byname'] = ' $a';
$string['cancel'] = '';
$string['categories'] = '   ';
$string['category'] = '';
$string['categoryadded'] = '  \'$a\' ';
$string['categorydeleted'] = '  \'$a\' ';
$string['categoryduplicate'] = '  \'$a\'  !';
$string['changedpassword'] = '   ';
$string['changepassword'] = '   ';
$string['changessaved'] = '  ';
$string['checkingbackup'] = '   ';
$string['checkingcourse'] = '   ';
$string['checkinginstances'] = '  ';
$string['checkingsections'] = '  ';
$string['checklanguage'] = ' ';
$string['choose'] = '';
$string['choosecourse'] = '  ';
$string['chooselivelogs'] = '   ';
$string['chooselogs'] = '     ';
$string['choosereportfilter'] = '   ';
$string['choosetheme'] = '  ';
$string['chooseuser'] = ' ';
$string['city'] = '/';
$string['cleaningtempdata'] = '  ';
$string['clicktochange'] = ' ';
$string['closewindow'] = '  ';
$string['comparelanguage'] = '   ';
$string['complete'] = '';
$string['configallowunenroll'] = '   \"\"         .               .';
$string['configautologinguests'] = '           .';
$string['configcountry'] = '   ,        .        .';
$string['configdebug'] = '            .     .';
$string['configdigestmailtime'] = '                .        (       \"corn\" ).';
$string['configdisplayloginfailures'] = '           .';
$string['configerrorlevel'] = '   PHP    .      .';
$string['configfilteruploadedfiles'] = '     Moodle     (HTML)                .';
$string['configforcelogin'] = 'ǡ           (   )    .               .';
$string['configforceloginforprofiles'] = '       ( )        .      (\"\")                          .';
$string['configframename'] = '          ߡ       \"\".';
$string['configfullnamedisplay'] = '         .           \"  + \",       ,      (   ) ';
$string['configgdversion'] = '      GD.         .         .';
$string['confightmleditor'] = '        HTML.                ( IE 5.5  ).      .';
$string['configidnumber'] = '    ()        ޡ ()         ɡ ()         .         . ';
$string['configintro'] = '            Moodle    .    ߡ       ȡ            .';
$string['configintroadmin'] = '    ()       , (  )           (  )           .         .';
$string['configintrosite'] = '        .              \" \"   .';
$string['configlang'] = '                .';
$string['configlangdir'] = '                   .';
$string['configlanglist'] = '               .                   .   :  en,es_es,fr,it';
$string['configlangmenu'] = '             .               .';
$string['configlocale'] = '     .          .           .       ȡ   .';
$string['configloglifetime'] = '         .         .           ǡ                .';
$string['configlongtimenosee'] = '      ɡ         .      .';
$string['configmaxbytes'] = '        .     (PHP upload_max_filesize )  (Apache LimitRequestBody). ߡ             .';
$string['configmaxeditingtime'] = '           ɡ .   30   . ';
$string['configproxyhost'] = '  <B></B>     proxy (  firewall)   ʡ      proxy   .    .';
$string['configsecureforms'] = '             .          (HTTP_REFERER)       .                  (Zonealarm)       (HTTP_REFERER)  .    .        (    )     ,               .   ,    \"\".';
$string['configsessioncookie'] = '     (cookie)   .                  .';
$string['configsessiontimeout'] = '             .               .';
$string['configslasharguments'] = '   ( ʡ )     \'slash arguments\' (   ).              proxy  .     PHP    .            (  )       .';
$string['configsmtphosts'] = '      SMTP          ( \'mail.a.com\' or \'mail.a.com;mail.b.com\' ).   ǡ       PHP   .';
$string['configsmtpuser'] = '      SMTP               .';
$string['configteacherassignteachers'] = '               \"\"          .';
$string['configunzip'] = '   unzip   (Unix ).        .';
$string['configuration'] = ' ';
$string['configvariables'] = ' ';
$string['configwarning'] = '     ʡ      .';
$string['configzip'] = '   zip   (Unix ).       .';
$string['confirm'] = '';
$string['confirmed'] = '  ';
$string['confirmednot'] = '   !';
$string['continue'] = '';
$string['cookiesenabled'] = '       Cookies ';
$string['copy'] = '';
$string['copyingcoursefiles'] = '   ';
$string['copyinguserfiles'] = '  ';
$string['copyingzipfile'] = '  ';
$string['copyrightnotice'] = '  ';
$string['cost'] = '';
$string['country'] = '';
$string['course'] = ' ';
$string['courseavailable'] = '    ';
$string['courseavailablenot'] = '     ';
$string['coursebackup'] = '   ';
$string['coursecategories'] = '  ';
$string['coursecategory'] = '  ';
$string['coursecreators'] = '  ';
$string['coursefiles'] = '  ';
$string['courseformats'] = '  ';
$string['coursegrades'] = '   ';
$string['courseinfo'] = '   ';
$string['courserestore'] = '   ';
$string['courses'] = '  ';
$string['courseupdates'] = '  ';
$string['courseuploadlimit'] = '    ';
$string['create'] = '';
$string['createaccount'] = '  ';
$string['createfolder'] = '   $a';
$string['createuserandpass'] = '          ';
$string['createziparchive'] = '  ';
$string['creatingcategoriesandquestions'] = '  ';
$string['creatingcoursemodules'] = '   ';
$string['creatingevents'] = ' ';
$string['creatinggroups'] = ' ';
$string['creatinglogentries'] = '  ';
$string['creatingnewcourse'] = '   ';
$string['creatingscales'] = ' ';
$string['creatingsections'] = ' ';
$string['creatingtemporarystructures'] = '  ';
$string['creatingusers'] = ' ';
$string['creatingxmlfile'] = '  XML';
$string['currentcourseadding'] = '    ';
$string['currentcoursedeleting'] = '    ';
$string['currentlanguage'] = ' ';
$string['currentlocaltime'] = '  ';
$string['currentpicture'] = ' ';
$string['currentrelease'] = '  ';
$string['currentversion'] = ' ';
$string['databasechecking'] = '   Moodle   $a->oldversion  $a->newversion...';
$string['databaseperformance'] = '  ';
$string['databasesetup'] = '  ';
$string['databasesuccess'] = '    ';
$string['databaseupgradebackups'] = '    $a';
$string['databaseupgradeblocks'] = '    $a';
$string['databaseupgrades'] = '  ';
$string['date'] = '';
$string['datemostrecentfirst'] = ' -  ';
$string['datemostrecentlast'] = ' -  ';
$string['day'] = '';
$string['days'] = '';
$string['decodinginternallinks'] = '  ';
$string['defaultcoursefullname'] = '    101';
$string['defaultcourseshortname'] = ' 101';
$string['defaultcoursestudent'] = '';
$string['defaultcoursestudents'] = '';
$string['defaultcoursesummary'] = '       ';
$string['defaultcourseteacher'] = '';
$string['defaultcourseteachers'] = '';
$string['delete'] = '';
$string['deleteall'] = ' ';
$string['deletecheck'] = ' $a ?';
$string['deletecheckfiles'] = '        ';
$string['deletecheckfull'] = '      $a ?';
$string['deletecheckwarning'] = '    ';
$string['deletecompletely'] = ' ';
$string['deletecourse'] = '  ';
$string['deletecoursecheck'] = '            ʿ';
$string['deleted'] = ' ';
$string['deletedactivity'] = '  $a';
$string['deletedcourse'] = '$a   ';
$string['deletednot'] = '  $a !';
$string['deleteselected'] = ' ';
$string['deletingcourse'] = ' $a';
$string['deletingexistingcoursedata'] = '    ';
$string['deletingolddata'] = '  ';
$string['department'] = '';
$string['description'] = '';
$string['disable'] = '';
$string['displayingfirst'] = '  $a->count $a->things ';
$string['displayingrecords'] = ' $a ';
$string['displayingusers'] = '  $a->start  $a->end';
$string['documentation'] = ' ';
$string['donotask'] = ' ';
$string['down'] = '';
$string['downloadexcel'] = '   ';
$string['downloadtext'] = '   ';
$string['doyouagree'] = '     ǿ';
$string['duplicate'] = ' ';
$string['duplicatinga'] = '  : $a';
$string['duplicatingain'] = '  $ a> what $ a> in';
$string['edit'] = ' $a';
$string['editcoursesettings'] = '   ';
$string['editfiles'] = ' ';
$string['editgroupprofile'] = '  ';
$string['editinga'] = ' $a';
$string['editmyprofile'] = '   ';
$string['editsummary'] = ' ';
$string['editthisactivity'] = '  ';
$string['editthiscategory'] = '  ';
$string['edituser'] = '  ';
$string['email'] = '  ';
$string['emailactive'] = '   ';
$string['emailagain'] = '  ';
$string['emailconfirm'] = '  ';
$string['emailconfirmation'] = ' $a->firstname,
     \'$a->sitename\'
  .
        :
  $a->link
              .    ߡ          .
  \'$a->sitename\' ,
$a->admin';
$string['emailconfirmationsubject'] = '$a  :';
$string['emailconfirmsent'] = '   <P>    <B>$a</B>
   <P>        
   <P>      ';
$string['emaildigest'] = '  ';
$string['emaildigestcomplete'] = ' (     )';
$string['emaildigestoff'] = '  (     )';
$string['emaildigestsubjects'] = ' (      )';
$string['emaildisable'] = '    ';
$string['emaildisableclick'] = '        ';
$string['emaildisplay'] = ' ';
$string['emaildisplaycourse'] = '        ';
$string['emaildisplayno'] = '    ';
$string['emaildisplayyes'] = '   ';
$string['emailenable'] = '    ';
$string['emailenableclick'] = '        ';
$string['emailexists'] = '    .';
$string['emailformat'] = ' ';
$string['emailmustbereal'] = '      ';
$string['emailpasswordconfirmation'] = '
$a->firstname,
 ( )     
\'$a->sitename\'
                :
$a->link
               .               
     ɡ    
$a->admin';
$string['emailpasswordconfirmationsubject'] = '$a   :';
$string['emailpasswordconfirmsent'] = '           <b>$a</b>
<p>      
        
$a->admin';
$string['emailpasswordsent'] = '     
<p>            
<b>$a->email</b>
<p>    ǡ   
<a href=$a->link>    </a>   ';
$string['enable'] = '';
$string['encryptedcode'] = ' ';
$string['enrolledincourse'] = '    ';
$string['enrolledincoursenot'] = '     ';
$string['enrolmentconfirmation'] = '        
<br />    ߿';
$string['enrolmentkey'] = ' ';
$string['enrolmentkeyfrom'] = '    \' \' -     <BR>
       $a';
$string['enrolmentkeyhint'] = '   .   <BR>
(  -    \'$a\'';
$string['enrolmentnew'] = '   $a';
$string['enrolmentnointernal'] = '    ';
$string['enrolmentnotyet'] = '         </ br> $a';
$string['enrolments'] = '';
$string['enrolperiod'] = ' ';
$string['entercourse'] = '    ';
$string['enteremailaddress'] = '          .';
$string['entries'] = '';
$string['error'] = '';
$string['errortoomanylogins'] = '     .   .';
$string['errorwhenconfirming'] = '        .                  ǡ           ';
$string['everybody'] = '';
$string['executeat'] = '  ';
$string['existing'] = '';
$string['existingadmins'] = ' ';
$string['existingcourse'] = '  ';
$string['existingcourseadding'] = '    ';
$string['existingcoursedeleting'] = '     ';
$string['existingcreators'] = '   ';
$string['existingstudents'] = ' ';
$string['existingteachers'] = ' ';
$string['feedback'] = '';
$string['file'] = '';
$string['filemissing'] = '$a  ';
$string['files'] = '';
$string['filesfolders'] = ' / ';
$string['filloutallfields'] = '      ';
$string['findmorecourses'] = '    ';
$string['firstdayofweek'] = '0';
$string['firstname'] = ' ';
$string['firsttime'] = '     ߿   ';
$string['followingoptional'] = '  ';
$string['followingrequired'] = '  ';
$string['force'] = '';
$string['forcedmode'] = ' ';
$string['forcelanguage'] = ' ';
$string['forceno'] = ' ';
$string['forgotten'] = '      ѿ';
$string['format'] = '';
$string['formathtml'] = ' HTML';
$string['formatplain'] = ' ';
$string['formatsocial'] = ' ';
$string['formattext'] = ' ';
$string['formattexttype'] = '';
$string['formattopics'] = ' ';
$string['formatweeks'] = ' ';
$string['formatwiki'] = ' ';
$string['from'] = '';
$string['frontpagecategorynames'] = '  ';
$string['frontpagecourselist'] = '   ';
$string['frontpagedescription'] = '  ';
$string['frontpageformat'] = '  ';
$string['frontpagenews'] = '  ';
$string['fulllistofcourses'] = '  ';
$string['fullname'] = ' ';
$string['fullnamedisplay'] = '$a->  $a-> ';
$string['fullprofile'] = '  ';
$string['fullsitename'] = '  ';
$string['gd1'] = 'GD 1.x  ';
$string['gd2'] = 'GD 2.x  ';
$string['gdneed'] = '   GD   ';
$string['gdnot'] = '   GD';
$string['gpl'] = '  (C) 2001-2002  Martin Dougiamas  (http://dougiamas.com)
      /       GNU General Public License      Free Software Foundation    2      .
     ɡ              .   ʡ     GNU General Public License:
http://www.gnu.org/copyleft/gpl.html';
$string['grade'] = '';
$string['grades'] = '';
$string['group'] = '';
$string['groupadd'] = '  ';
$string['groupaddusers'] = '   ';
$string['groupfor'] = '';
$string['groupinfo'] = '   ';
$string['groupinfomembers'] = '   ';
$string['groupinfopeople'] = '   ';
$string['groupmemberssee'] = '  ';
$string['groupmembersselected'] = '  ';
$string['groupmode'] = ' ';
$string['groupmodeforce'] = '  ';
$string['groupmy'] = '';
$string['groupnonmembers'] = '   ';
$string['groupnotamember'] = '      ';
$string['grouprandomassign'] = '   ';
$string['groupremove'] = '  ';
$string['groupremovemembers'] = '  ';
$string['groups'] = '';
$string['groupsnone'] = '  ';
$string['groupsseparate'] = ' ';
$string['groupsvisible'] = ' ';
$string['guestskey'] = '    ';
$string['guestsno'] = '   ';
$string['guestsnotallowed'] = ' \'$a\'    ';
$string['guestsyes'] = '   ';
$string['guestuser'] = ' ';
$string['guestuserinfo'] = '          .';
$string['help'] = '';
$string['helpemoticons'] = '  ';
$string['helpformatting'] = '  ';
$string['helphtml'] = '  html';
$string['helpindex'] = '   ';
$string['helppicture'] = '  ';
$string['helpquestions'] = '  ';
$string['helpreading'] = ' ';
$string['helprichtext'] = '   Richtext HTML';
$string['helpsummaries'] = '  ';
$string['helptext'] = '  ';
$string['helpwiki'] = '    ';
$string['helpwriting'] = ' ';
$string['hiddensections'] = ' ';
$string['hiddensectionscollapsed'] = '       ';
$string['hiddensectionsinvisible'] = '    ';
$string['hide'] = '';
$string['hidepicture'] = ' ';
$string['hits'] = '';
$string['hitsoncourse'] = '  $a->coursename  $a->username';
$string['hitsoncoursetoday'] = '    $a->coursename  $a->username';
$string['home'] = ' ';
$string['hour'] = '';
$string['hours'] = '';
$string['howtomakethemes'] = '   ';
$string['htmleditor'] = '  Richtext HTML ( IE 5.5  )';
$string['htmleditoravailable'] = ' Richtext ';
$string['htmleditordisabled'] = '    Richtext   ';
$string['htmleditordisabledadmin'] = '     Richtext  ';
$string['htmleditordisabledbrowser'] = ' Richtext      IE 5.5  ';
$string['htmlformat'] = 'Pretty HTML ';
$string['icqnumber'] = 'ICQ ';
$string['idnumber'] = '  ';
$string['inactive'] = ' ';
$string['include'] = '';
$string['includeallusers'] = '  ';
$string['includecoursefiles'] = '   ';
$string['includecourseusers'] = '   ';
$string['included'] = '';
$string['includelogentries'] = '  ';
$string['includemodules'] = ' ';
$string['includeneededusers'] = '   ';
$string['includenoneusers'] = '  ';
$string['includeuserfiles'] = '  ';
$string['institution'] = '';
$string['invalidemail'] = '    ';
$string['invalidlogin'] = '      ѡ   .';
$string['ip_address'] = ' IP';
$string['jumpto'] = ' ...';
$string['keep'] = '';
$string['langltr'] = '     ';
$string['langrtl'] = '     ';
$string['language'] = '';
$string['languagegood'] = '    ';
$string['lastaccess'] = ' ';
$string['lastedited'] = ' ';
$string['lastlogin'] = ' ';
$string['lastmodified'] = ' ';
$string['lastname'] = ' ';
$string['latestlanguagepack'] = '       moodle.org';
$string['latestnews'] = ' ';
$string['leavetokeep'] = '         ';
$string['license'] = 'GPL ';
$string['list'] = '';
$string['listfiles'] = '   $a';
$string['listofallpeople'] = '  ';
$string['livelogs'] = '   ';
$string['locale'] = 'en';
$string['location'] = '';
$string['loggedinas'] = '   $a';
$string['loggedinnot'] = '  .';
$string['login'] = '';
$string['login_failure_logs'] = '   ';
$string['loginas'] = ' ';
$string['loginguest'] = '  ';
$string['loginsite'] = '  ';
$string['loginsteps'] = ' !                 : 

   <OL size=2>
   <LI>  <A HREF=$a> </A>.
   <LI>      .
   <LI>       .
   <LI>     .
   <LI>        .
   <LI>            (    )               .
   <LI>    \'\' \'\' -      .   \'\'\'\'   .   
   <LI>           \" \"   .
   </OL>';
$string['loginstepsnone'] = '!<P>        .<P>              !<P>             .';
$string['loginto'] = '  $a';
$string['loginusing'] = '    ';
$string['logout'] = '';
$string['logs'] = '';
$string['mainmenu'] = ' ';
$string['makeafolder'] = ' ';
$string['makeeditable'] = '  \'$a\'        ( apache)          ';
$string['manageblocks'] = '';
$string['managedatabase'] = '  ';
$string['managefilters'] = '';
$string['managemodules'] = '';
$string['markedthistopic'] = '    ';
$string['markthistopic'] = '     ';
$string['maximumchars'] = '  $a  ';
$string['maximumgrade'] = ' ';
$string['maximumshort'] = ' ';
$string['maximumupload'] = '  ';
$string['maxsize'] = ' : $a';
$string['min'] = ' ';
$string['mins'] = '';
$string['miscellaneous'] = '';
$string['missingcategory'] = '   ';
$string['missingcity'] = '/  ';
$string['missingcountry'] = '   ';
$string['missingdescription'] = '   ';
$string['missingemail'] = '     ';
$string['missingfirstname'] = '     ';
$string['missingfullname'] = '     ';
$string['missinglastname'] = '     ';
$string['missingname'] = ' ';
$string['missingnewpassword'] = '      ';
$string['missingpassword'] = '      ';
$string['missingshortname'] = '     ';
$string['missingshortsitename'] = '      ';
$string['missingsitedescription'] = '      ';
$string['missingsitename'] = '     ';
$string['missingstrings'] = '   ';
$string['missingstudent'] = '   ';
$string['missingsummary'] = ' ';
$string['missingteacher'] = '   ';
$string['missingurl'] = '  ';
$string['missingusername'] = '  ';
$string['modified'] = ' ';
$string['moduledeleteconfirm'] = '      \'$a\'.           .         ݿ';
$string['moduledeletefiles'] = '     \'$a->module\'  .             :$a->directory';
$string['modulesetup'] = '   ';
$string['modulesuccess'] = '$a     ';
$string['moodleversion'] = ' ';
$string['more'] = '';
$string['mostrecently'] = '';
$string['move'] = '';
$string['movecategoryto'] = '  :';
$string['movecourseto'] = '   :';
$string['movedown'] = '  ';
$string['movefilestohere'] = '   ';
$string['movefull'] = ' $a   ';
$string['movehere'] = '  ';
$string['moveleft'] = '  ';
$string['moveright'] = '  ';
$string['moveselectedcoursesto'] = '    ';
$string['movetoanotherfolder'] = '   ';
$string['moveup'] = '  ';
$string['mustconfirm'] = '    ';
$string['mycourses'] = ' ';
$string['name'] = '';
$string['namesocial'] = '';
$string['nametopics'] = '';
$string['nameweeks'] = '';
$string['needed'] = '';
$string['never'] = '';
$string['neverdeletelogs'] = '   ';
$string['new'] = '';
$string['newaccount'] = ' ';
$string['newcourse'] = '  ';
$string['newpassword'] = '  ';
$string['newpasswordtext'] = ' $a->firstname,
                
     :
    : $a->username
    : $a->newpassword
       :
   $a->link
              .    ߡ          .
  \'$a->sitename\' ,
$a->signoff';
$string['newpicture'] = '  ';
$string['newsitem'] = ' ';
$string['newsitems'] = ' ';
$string['newsitemsnumber'] = '   ';
$string['newuser'] = ' ';
$string['newusers'] = ' ';
$string['next'] = '';
$string['no'] = '';
$string['nobody'] = ' ';
$string['nocoursesfound'] = '         \'$a\'';
$string['nocoursesyet'] = '     ';
$string['noexistingadmins'] = '         ';
$string['noexistingcreators'] = '  ';
$string['noexistingstudents'] = '  ';
$string['noexistingteachers'] = '   ';
$string['nofilesselected'] = '      ';
$string['nofilesyet'] = '       ';
$string['nograde'] = '  ';
$string['noimagesyet'] = '        ';
$string['nomorecourses'] = '      ';
$string['none'] = ' ';
$string['nopotentialadmins'] = '   ';
$string['nopotentialcreators'] = '     ';
$string['nopotentialstudents'] = '   ';
$string['nopotentialteachers'] = '   ';
$string['normal'] = '';
$string['normalfilter'] = ' ';
$string['nostudentsfound'] = '    $a';
$string['nostudentsyet'] = '         ';
$string['nosuchemail'] = '     ';
$string['notavailable'] = ' ';
$string['noteachersyet'] = '       ';
$string['notenrolled'] = '$a      ';
$string['noteuserschangednonetocourse'] = ':        .    ';
$string['nothingnew'] = '     .';
$string['notincluded'] = ' ';
$string['notingroup'] = '            ';
$string['nousersmatching'] = '   \'$a\'  ';
$string['nousersyet'] = '    ';
$string['now'] = '';
$string['numberweeks'] = ' /';
$string['numdays'] = '$a ';
$string['numhours'] = '$a ';
$string['numminutes'] = '$a ';
$string['numseconds'] = '$a  ';
$string['numviews'] = '$a ';
$string['numweeks'] = '$a ';
$string['numwords'] = '$a ';
$string['numyears'] = '$a ';
$string['ok'] = '';
$string['opentoguests'] = ' ';
$string['optional'] = '';
$string['order'] = '';
$string['other'] = '';
$string['outline'] = '';
$string['page'] = '';
$string['participants'] = '';
$string['password'] = ' ';
$string['passwordchanged'] = '   ';
$string['passwordconfirmchange'] = '   ';
$string['passwordrecovery'] = '   ';
$string['passwordsdiffer'] = '   ';
$string['passwordsent'] = '   ';
$string['passwordsenttext'] = '   <P>     $a->email.
   <P><B>      </B>
   <P>    ɡ   
   <A HREF=$a->link>         </A>.';
$string['people'] = '';
$string['personalprofile'] = ' ';
$string['phone'] = '';
$string['phpinfo'] = ' PHP';
$string['popupwindow'] = '    ';
$string['potentialadmins'] = ' ';
$string['potentialcreators'] = '   ';
$string['potentialstudents'] = ' ';
$string['potentialteachers'] = ' ';
$string['preferredlanguage'] = ' ';
$string['preview'] = '';
$string['previeworchoose'] = '      ';
$string['previous'] = '';
$string['publicdirectory'] = ' ';
$string['publicdirectory0'] = '    ';
$string['publicdirectory1'] = '     ';
$string['publicdirectory2'] = '       ';
$string['publicsitefileswarning'] = ':          ';
$string['question'] = '';
$string['readinginfofrombackup'] = '    ';
$string['readme'] = '';
$string['recentactivity'] = ' ';
$string['recentactivityreport'] = '   ';
$string['refreshingevents'] = ' ';
$string['registration'] = ' ';
$string['registrationemail'] = '  ';
$string['registrationinfo'] = '<p>        moodle.org.  .
                     
<p>ǡ          .                 
<p>           
<p>        ɡ               ';
$string['registrationno'] = ':     ';
$string['registrationsend'] = '    moodle.org';
$string['registrationyes'] = ':    ';
$string['removeadmin'] = ' ';
$string['removecreator'] = '   ';
$string['removestudent'] = ' ';
$string['removeteacher'] = ' ';
$string['rename'] = ' ';
$string['renamefileto'] = '  <b>$a</b> ';
$string['required'] = '';
$string['requireskey'] = '      ';
$string['requirespayment'] = '        ';
$string['resortcoursesbyname'] = '   ';
$string['resources'] = '';
$string['restore'] = '';
$string['restorecancelled'] = ' ';
$string['restorecoursenow'] = '    !';
$string['restorefinished'] = '  ';
$string['restoreto'] = ' ';
$string['returningtosite'] = '       ';
$string['revert'] = '';
$string['role'] = '';
$string['savechanges'] = ' ';
$string['saveto'] = ' ';
$string['scale'] = '';
$string['scales'] = '';
$string['scalescustom'] = '  ';
$string['scalescustomcreate'] = '  ';
$string['scalescustomno'] = '     ';
$string['scalesstandard'] = ' ';
$string['scalestip'] = '  ɡ   Ӓ    ';
$string['schedule'] = '';
$string['scheduledbackupstatus'] = '    ';
$string['search'] = '';
$string['searchagain'] = '  ';
$string['searchcourses'] = '  ';
$string['searchhelp'] = '        <p>word:      . <br>+word:     . <br>word:      ';
$string['searchresults'] = ' ';
$string['sec'] = '';
$string['secs'] = '';
$string['section'] = '';
$string['sections'] = '';
$string['select'] = '';
$string['selectacountry'] = ' ';
$string['selectednowmove'] = '$a  .          ,   ';
$string['senddetails'] = '   ';
$string['separateandconnected'] = '   ';
$string['serverlocaltime'] = '  ';
$string['settings'] = '';
$string['shortname'] = ' ';
$string['shortnametaken'] = '       ($a)';
$string['shortsitename'] = '    (    )';
$string['show'] = '';
$string['showall'] = '  $a';
$string['showallcourses'] = '   ';
$string['showalltopics'] = '  ';
$string['showallusers'] = '  ';
$string['showallweeks'] = '  ';
$string['showgrades'] = ' ';
$string['showlistofcourses'] = '   ';
$string['showonlytopic'] = '   $a';
$string['showonlyweek'] = '   $a';
$string['showrecent'] = '  ';
$string['showreports'] = '  ';
$string['showtheselogs'] = ' ';
$string['since'] = '';
$string['sincelast'] = '  ';
$string['site'] = '';
$string['siteerrors'] = ' ';
$string['sitefiles'] = ' ';
$string['sitelogs'] = '  ';
$string['sitenews'] = ' ';
$string['sites'] = '';
$string['sitesection'] = '  ';
$string['sitesettings'] = '  ';
$string['size'] = '';
$string['sizeb'] = '';
$string['sizegb'] = '';
$string['sizekb'] = ' ';
$string['sizemb'] = ' ';
$string['socialheadline'] = '  -  ';
$string['someallowguest'] = '     ';
$string['someerrorswerefound'] = '     ɡ         .';
$string['sortby'] = ' ';
$string['specifyname'] = '   ';
$string['startdate'] = '   ';
$string['startsignup'] = '  ';
$string['state'] = ' / ';
$string['status'] = '';
$string['strftimedate'] = '%%d %%B %%Y';
$string['strftimedateshort'] = '%%d %%B';
$string['strftimedatetime'] = '%%d %%B %%Y, %%I:%%M %%p';
$string['strftimedaydate'] = '%%A, %%d %%B %%Y';
$string['strftimedaydatetime'] = '%%A, %%d %%B %%Y, %%I:%%M %%p';
$string['strftimemonthyear'] = '%%B %%Y';
$string['strftimerecent'] = '%%d %%b, %%H:%%M';
$string['strftimerecentfull'] = '%%a, %%d %%b %%Y, %%I:%%M %%p';
$string['strftimetime'] = '%%I:%%M %%p';
$string['stringsnotset'] = '      $a';
$string['studentnotallowed'] = '!         \'$a\'';
$string['students'] = '';
$string['subcategories'] = ' ';
$string['success'] = '';
$string['summary'] = '';
$string['summaryof'] = '   $a';
$string['supplyinfo'] = '   ';
$string['teacheronly'] = '  $a  ';
$string['teacherroles'] = '$a ';
$string['teachers'] = '';
$string['textediting'] = '  ';
$string['texteditor'] = '   ';
$string['textformat'] = '  ';
$string['thanks'] = '';
$string['theme'] = '';
$string['themes'] = '';
$string['themesaved'] = '   ';
$string['thischarset'] = 'windows-1256';
$string['thisdirection'] = 'rtl';
$string['thislanguage'] = '&#1593;&#1585;&#1576;&#1610;';
$string['time'] = '';
$string['timezone'] = ' ';
$string['to'] = '';
$string['today'] = '';
$string['todaylogs'] = ' ';
$string['toomanytoshow'] = '    ';
$string['top'] = '';
$string['topic'] = '';
$string['topichide'] = '    $a';
$string['topicoutline'] = ' ';
$string['topicshow'] = '    $a';
$string['total'] = '';
$string['turneditingoff'] = ' ';
$string['turneditingon'] = ' ';
$string['undecided'] = ' ';
$string['unenrol'] = ' ';
$string['unenrolallstudents'] = '   ';
$string['unenrolallstudentssure'] = '             ';
$string['unenrolme'] = '   $a';
$string['unenrolsure'] = '       $a    ?';
$string['unknowncategory'] = '  ';
$string['unlimited'] = ' ';
$string['unpacking'] = '  $a';
$string['unsafepassword'] = '    -  ';
$string['unusedaccounts'] = '      $a     ';
$string['unzip'] = '';
$string['unzippingbackup'] = '  ';
$string['up'] = '';
$string['update'] = '';
$string['updated'] = '  $a';
$string['updatemyprofile'] = '  ';
$string['updatesevery'] = '   $a ';
$string['updatethis'] = '  $a';
$string['updatethiscourse'] = '   ';
$string['updatinga'] = ' $a';
$string['updatingain'] = ' $a->what   $a->in';
$string['upload'] = '';
$string['uploadafile'] = ' ';
$string['uploadedfileto'] = '  $a->file  $a->directory';
$string['uploadnofilefound'] = '    ݡ       .';
$string['uploadnotallowed'] = '   ';
$string['uploadproblem'] = '      . $a(   ?)';
$string['uploadthisfile'] = '  ';
$string['uploadusers'] = ' ';
$string['usedinnplaces'] = '  $a ';
$string['user'] = '';
$string['userconfirmed'] = '  $a';
$string['userdata'] = ' ';
$string['userdeleted'] = '    ';
$string['userdescription'] = '';
$string['userfiles'] = ' ';
$string['username'] = ' ';
$string['usernameexists'] = '      ';
$string['usernotconfirmed'] = '    $a';
$string['userprofilefor'] = ' $a ';
$string['users'] = '';
$string['usersnew'] = ' ';
$string['userzones'] = ' ';
$string['usingexistingcourse'] = '   ';
$string['version'] = '';
$string['view'] = '';
$string['webpage'] = ' ';
$string['week'] = '';
$string['weekhide'] = '    $a';
$string['weeklyoutline'] = ' ';
$string['weekshow'] = '    $a';
$string['welcometocourse'] = '  $a';
$string['welcometocoursetext'] = '  $a->coursename!
                   
 $a->profileurl';
$string['whattocallzip'] = '    ؿ';
$string['withchosenfiles'] = '  ';
$string['withoutuserdata'] = '   ';
$string['withuserdata'] = ' ';
$string['wordforstudent'] = '   ';
$string['wordforstudenteg'] = ': ȡ ߡ ӡ ';
$string['wordforstudents'] = '   ';
$string['wordforstudentseg'] = ': ȡ   ';
$string['wordforteacher'] = '   ';
$string['wordforteachereg'] = ': ӡ ѡ  ';
$string['wordforteachers'] = '  ';
$string['wordforteacherseg'] = ':    ';
$string['writingcategoriesandquestions'] = '   ';
$string['writingcoursedata'] = '    ';
$string['writingeventsinfo'] = '   ';
$string['writinggeneralinfo'] = '   ';
$string['writinggroupsinfo'] = '    ';
$string['writingheader'] = '   ';
$string['writingloginfo'] = '   ';
$string['writingmoduleinfo'] = '   ';
$string['writingscalesinfo'] = '   ';
$string['writinguserinfo'] = '   ';
$string['wrongpassword'] = '      ';
$string['yes'] = '';
$string['youareabouttocreatezip'] = '       ';
$string['youaregoingtorestorefrom'] = '      ';
$string['yourlastlogin'] = '   ';
$string['yourself'] = ' ';
$string['yourteacher'] = '  $a';
$string['zippingbackup'] = '  ';

?>
